@@ -1,6 +1,6 @@
 #' @export
-getParamSet.BaseWrapper = function(learner) {
-  c(learner$par.set, getParamSet(learner$next.learner))
+getParamSet.BaseWrapper = function(x) {
+  c(x$par.set, getParamSet(x$next.learner))
 }
 
 
@@ -29,7 +29,7 @@ removeHyperPars.BaseWrapper = function(learner, ids) {
   i = intersect(names(learner$par.vals), ids)
   if (length(i) > 0L)
     learner = removeHyperPars.Learner(learner, i)
-  learner$next.learner = removeHyperPars.Learner(learner$next.learner, setdiff(ids, i))
+  learner$next.learner = removeHyperPars(learner$next.learner, setdiff(ids, i))
   return(learner)
 }
 
