@@ -92,12 +92,19 @@ print.Filter = function(x, ...) {
   catf("Supported features: %s", collapse(x$supported.features))
 }
 
+#' Minimum redundancy, maximum relevance filter \dQuote{mrmr} computes the
+#' mutual information between the target and each individual feature minus the
+#' average mutual information of previously selected features and this feature
+#' using the \pkg{mRMRe} package.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
 makeFilter(
   name = "mrmr",
   desc = "Minimum redundancy, maximum relevance filter",
   pkg  = "mRMRe",
-  supported.tasks = c("classif", "regr", "surv"),
-  supported.features = c("numerics", "factors"),
+  supported.tasks = c("regr", "surv"),
+  supported.features = c("numerics", "ordered"),
   fun = function(task, nselect, ...) {
     if (inherits(task, "SurvTask")) {
       data = getTaskData(task, target.extra = TRUE, recode.target = "rcens")
@@ -109,8 +116,6 @@ makeFilter(
     }
 
     # some required conversions
-    ind = vlapply(data, is.factor)
-    data[ind] = lapply(data[ind], as.ordered)
     ind = which(vlapply(data, is.integer))
     data[ind] = lapply(data[ind], as.double)
     data = mRMRe::mRMR.data(data = data)
@@ -123,6 +128,12 @@ makeFilter(
     setNames(scores, res@feature_names[as.integer(mRMRe::solutions(res)[[1L]])])
 })
 
+#' Filter \dQuote{carscore} determines the \dQuote{Correlation-Adjusted (marginal) coRelation
+#' scores} (short CAR scores). The CAR scores for a set of features are defined as the
+#' correlations between the target and the decorrelated features.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
 makeFilter(
   name = "carscore",
   desc = "CAR scores",
@@ -136,14 +147,25 @@ makeFilter(
   }
 )
 
-makeFilter(
-  name = "rf.importance",
+#' Filter \dQuote{randomForestSRC.rfsrc} computes the importance of random forests
+#' fitted in package \pkg{randomForestSRC}. The concrete method is selected via
+#' the \code{method} parameter. Possible values are \code{permute} (default), \code{random},
+#' \code{anti}, \code{permute.ensemble}, \code{random.ensemble}, \code{anti.ensemble}.
+#' See the VIMP section in the docs for \code{\link[randomForestSRC]{rfsrc}} for
+#' details.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
+rf.importance = makeFilter(
+  name = "randomForestSRC.rfsrc",
   desc = "Importance of random forests fitted in package 'randomForestSRC'. Importance is calculated using argument 'permute'.",
   pkg  = "randomForestSRC",
   supported.tasks = c("classif", "regr", "surv"),
-  supported.features = c("numerics", "factors"),
-  fun = function(task, nselect, ...) {
-    im = randomForestSRC::rfsrc(getTaskFormula(task), data = getTaskData(task), proximity = FALSE, forest = FALSE, importance = "permute", ...)$importance
+  supported.features = c("numerics", "factors", "ordered"),
+  fun = function(task, nselect, method = "permute", ...) {
+    assertChoice(method, choices = c("permute", "random", "anti", "permute.ensemble", "random.ensemble",  "anti.ensemble"))
+    im = randomForestSRC::rfsrc(getTaskFormula(task), data = getTaskData(task), proximity = FALSE,
+      forest = FALSE, importance = method, ...)$importance
     if (inherits(task, "ClassifTask")) {
       ns = rownames(im)
       y = im[, "all"]
@@ -154,26 +176,52 @@ makeFilter(
     setNames(y, ns)
   }
 )
+.FilterRegister[["rf.importance"]] = rf.importance
+.FilterRegister[["rf.importance"]]$desc = "Importance of random forests fitted in package 'randomForestSRC'. Importance is calculated using argument 'permute'. (DEPRECATED)"
+.FilterRegister[["rf.importance"]]$fun = function(...) {
+  .Deprecated(old = "Filter 'rf.importance'", new = "Filter 'randomForestSRC.rfsrc'")
+  .FilterRegister[["randomForestSRC.rfsrc"]]$fun(...)
+}
 
-makeFilter(
-  name = "rf.min.depth",
-  desc = "Minimal depth of random forest fitted in package 'randomForestSRC'",
+#' Filter \dQuote{randomForestSRC.var.select} uses the minimal depth variable
+#' selection proposed by Ishwaran et al. (2010) (\code{method = "md"}) or a
+#' variable hunting approach (\code{method = "vh"} or \code{method = "vh.vimp"}).
+#' The minimal depth measure is the default.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
+rf.min.depth = makeFilter(
+  name = "randomForestSRC.var.select",
+  desc = "Minimal depth of / variable hunting via method var.select on random forests fitted in package 'randomForestSRC'.",
   pkg  = "randomForestSRC",
   supported.tasks = c("classif", "regr", "surv"),
-  supported.features = c("numerics", "factors"),
-  fun = function(task, nselect, ...) {
+  supported.features = c("numerics", "factors", "ordered"),
+  fun = function(task, nselect, method = "md", ...) {
     im = randomForestSRC::var.select(getTaskFormula(task), getTaskData(task),
-      method = "md", verbose = FALSE, ...)$md.obj$order
+      method = method, verbose = FALSE, ...)$md.obj$order
     setNames(-im[, 1L], rownames(im))
   }
 )
+.FilterRegister[["rf.min.depth"]] = rf.min.depth
+.FilterRegister[["rf.min.depth"]]$desc = "Minimal depth of random forest fitted in package 'randomForestSRC. (DEPRECATED)"
+.FilterRegister[["rf.min.depth"]]$fun = function(...) {
+  .Deprecated(old = "Filter 'rf.min.depth'", new = "Filter 'randomForestSRC.var.select'")
+  .FilterRegister[["randomForestSRC.var.select"]]$fun(...)
+}
 
+#' Permutation importance of random forests fitted in package \pkg{party}.
+#' The implementation follows the principle of mean decrese in accuracy used
+#' by the \pkg{randomForest} package (see description of \dQuote{randomForest.importance})
+#' filter.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
 makeFilter(
   name = "cforest.importance",
   desc = "Permutation importance of random forest fitted in package 'party'",
   pkg = "party",
   supported.tasks = c("classif", "regr", "surv"),
-  supported.features = c("numerics", "factors"),
+  supported.features = c("numerics", "factors", "ordered"),
   fun = function(task, nselect, mtry = 5L, ...) {
     args = list(...)
     # we need to set mtry, which is 5 by default in cforest, to p if p < mtry
@@ -195,30 +243,80 @@ makeFilter(
   }
 )
 
+#' Filter \dQuote{randomForest.importance} makes use of the \code{\link[randomForest]{importance}}
+#' from package \pkg{randomForest}. The importance measure to use is selected via
+#' the \code{method} parameter:
+#' \describe{
+#'   \item{oob.accuracy}{Permutation of Out of Bag (OOB) data.}
+#'   \item{node.impurity}{Total decrease in node impurity.}
+#' }
+#'
+#' @rdname makeFilter
+#' @name makeFilter
+makeFilter(
+  name = "randomForest.importance",
+  desc = "Importance based on OOB-accuracy or node inpurity of random forest fitted in package 'randomForest'.",
+  pkg = "randomForest",
+  supported.tasks = c("classif", "regr"),
+  supported.features = c("numerics", "factors"),
+  fun = function(task, nselect, method = "oob.accuracy", ...) {
+    assertChoice(method, choices = c("oob.accuracy", "node.impurity"))
+    type = if (method == "oob.accuracy") 1L else 2L
+    # no need to set importance = TRUE for node impurity (type = 2)
+    rf = randomForest::randomForest(getTaskFormula(task), data = getTaskData(task),
+      keep.forest = FALSE, importance = (type != 2L))
+    im = randomForest::importance(rf, type = type, ...)
+    setNames(im, rownames(im))
+  }
+)
+
+#' The Pearson correlation between each feature and the target is used as an indicator
+#' of feature importance. Rows with NA values are not taken into consideration.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
 makeFilter(
   name = "linear.correlation",
   desc = "Pearson correlation between feature and target",
-  pkg  = "FSelector",
+  pkg  = "Rfast",
   supported.tasks = "regr",
   supported.features = "numerics",
   fun = function(task, nselect, ...) {
-    y = FSelector::linear.correlation(getTaskFormula(task), data = getTaskData(task))
-    setNames(y[["attr_importance"]], getTaskFeatureNames(task))
+    d = getTaskData(task, target.extra = TRUE)
+    y = Rfast::correls(d$target, d$data, type = "pearson")
+    for (i in which(is.na(y[, "correlation"]))) {
+      y[i, "correlation"] = cor(d$target, d$data[,i], use = "complete.obs")
+    }
+    setNames(abs(y[, "correlation"]), getTaskFeatureNames(task))
   }
 )
 
+#' The Spearman correlation between each feature and the target is used as an indicator
+#' of feature importance. Rows with NA values are not taken into consideration.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
 makeFilter(
   name = "rank.correlation",
   desc = "Spearman's correlation between feature and target",
-  pkg  = "FSelector",
+  pkg  = "Rfast",
   supported.tasks = "regr",
   supported.features = "numerics",
   fun = function(task, nselect, ...) {
-    y = FSelector::rank.correlation(getTaskFormula(task), data = getTaskData(task))
-    setNames(y[["attr_importance"]], getTaskFeatureNames(task))
+    d = getTaskData(task, target.extra = TRUE)
+    y = Rfast::correls(d$target, d$data, type = "spearman")
+    for (i in which(is.na(y[, "correlation"]))) {
+      y[i, "correlation"] = cor(d$target, d$data[,i], use = "complete.obs", method = "spearman")
+    }
+    setNames(abs(y[, "correlation"]), getTaskFeatureNames(task))
   }
 )
 
+#' Filter \dQuote{information.gain} uses the entropy-based information gain
+#' between each feature and target individually as an importance measure.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
 makeFilter(
   name = "information.gain",
   desc = "Entropy-based information gain between feature and target",
@@ -231,6 +329,11 @@ makeFilter(
   }
 )
 
+#' Filter \dQuote{gain.ratio} uses the entropy-based information gain ratio
+#' between each feature and target individually as an importance measure.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
 makeFilter(
   name = "gain.ratio",
   desc = "Entropy-based gain ratio between feature and target",
@@ -243,6 +346,11 @@ makeFilter(
   }
 )
 
+#' Filter \dQuote{symmetrical.uncertainty} uses the entropy-based symmetrical uncertainty
+#' between each feature and target individually as an importance measure.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
 makeFilter(
   name = "symmetrical.uncertainty",
   desc = "Entropy-based symmetrical uncertainty between feature and target",
@@ -255,6 +363,15 @@ makeFilter(
   }
 )
 
+#' The chi-square test is a statistical test of independence to determine whether
+#' two variables are independent. Filter \dQuote{chi.squared} applies this
+#' test in the following way. For each feature the chi-square test statistic is
+#' computed checking if there is a dependency between the feature and the target
+#' variable. Low values of the test statistic indicate a poor relationship. High
+#' values, i.e., high dependency identifies a feature as more important.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
 makeFilter(
   name = "chi.squared",
   desc = "Chi-squared statistic of independence between feature and target",
@@ -267,6 +384,22 @@ makeFilter(
   }
 )
 
+#' Filter \dQuote{relief} is based on the feature selection algorithm \dQuote{ReliefF}
+#' by Kononenko et al., which is a generalization of the orignal \dQuote{Relief}
+#' algorithm originally proposed by Kira and Rendell. Feature weights are initialized
+#' with zeros. Then for each instance \code{sample.size} instances are sampled,
+#' \code{neighbours.count} nearest-hit and nearest-miss neighbours are computed
+#' and the weight vector for each feature is updated based on these values.
+#'
+#' @references
+#' Kira, Kenji and Rendell, Larry (1992). The Feature Selection Problem: Traditional
+#' Methods and a New Algorithm. AAAI-92 Proceedings.
+#'
+#' Kononenko, Igor et al. Overcoming the myopia of inductive learning algorithms
+#' with RELIEFF (1997), Applied Intelligence, 7(1), p39-55.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
 makeFilter(
   name = "relief",
   desc = "RELIEF algorithm",
@@ -274,11 +407,19 @@ makeFilter(
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors"),
   fun = function(task, nselect, ...) {
-    y = FSelector::relief(getTaskFormula(task), data = getTaskData(task))
+    y = FSelector::relief(getTaskFormula(task), data = getTaskData(task), ...)
     setNames(y[["attr_importance"]], getTaskFeatureNames(task))
   }
 )
 
+#' Filter \dQuote{oneR} makes use of a simple \dQuote{One-Rule} (OneR) learner to
+#' determine feature importance. For this purpose the OneR learner generates one
+#' simple association rule for each feature in the data individually and computes
+#' the total error. The lower the error value the more important the correspoding
+#' feature.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
 makeFilter(
   name = "oneR",
   desc = "oneR association rule",
@@ -286,17 +427,26 @@ makeFilter(
   supported.tasks = c("classif", "regr"),
   supported.features = c("numerics", "factors"),
   fun = function(task, nselect, ...) {
+    print(getTaskFormula(task))
     y = FSelector::oneR(getTaskFormula(task), data = getTaskData(task))
     setNames(y[["attr_importance"]], getTaskFeatureNames(task))
   }
 )
 
+#' The \dQuote{univariate.model.score} feature filter resamples an \pkg{mlr}
+#' learner specified via \code{perf.learner} for each feature individually
+#' with randomForest from package \pkg{rpart} being the default learner.
+#' Further parameter are the resamling strategey \code{perf.resampling} and
+#' the performance measure \code{perf.measure}.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
 univariate = makeFilter(
   name = "univariate.model.score",
   desc = "Resamples an mlr learner for each input feature individually. The resampling performance is used as filter score, with rpart as default learner.",
   pkg  = character(0L),
   supported.tasks = c("classif", "regr", "surv"),
-  supported.features = c("numerics", "factors"),
+  supported.features = c("numerics", "factors", "ordered"),
   fun = function(task, nselect, perf.learner = NULL, perf.measure = NULL, perf.resampling = NULL, ...) {
     typ = getTaskType(task)
     if (is.null(perf.learner))
@@ -335,22 +485,42 @@ univariate = makeFilter(
   .FilterRegister[["univariate.model.score"]]$fun(...)
 }
 
+#' Filter \dQuote{anova.test} is based on the Analysis of Variance (ANOVA) between
+#' feature and class. The value of the F-statistic is used as a measure of feature
+#' importance.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
 makeFilter(
   name = "anova.test",
   desc = "ANOVA Test for binary and multiclass classification tasks",
-  pkg = character(0L),
+  pkg = "Rfast",
   supported.tasks = c("classif"),
   supported.features = c("numerics"),
   fun = function(task, nselect, ...) {
-    data = getTaskData(task)
-    sapply(getTaskFeatureNames(task), function(feat.name) {
-      f = as.formula(stri_paste(feat.name,"~",getTaskTargetNames(task)))
-      aov.t = aov(f, data = data)
-      summary(aov.t)[[1]][1,'F value']
-    })
+    d = getTaskData(task, target.extra = TRUE)
+    y = as.integer(d$target)
+    X = as.matrix(d$data)
+    an = Rfast::anovas(X, y)
+    for (i in which(is.na(an[, "F value"]))) {
+      j = !is.na(X[,i])
+      if (any(j)) {
+        an[i, ] = Rfast::anovas(X[j, i, drop = FALSE], y[j]) 
+      }
+    }
+    setNames(an[, "F value"], getTaskFeatureNames(task))
   }
 )
 
+#' Filter \dQuote{kruskal.test} applies a Kruskal-Wallis rank sum test of the
+#' null hypothesis that the location parameters of the distribution of a feature
+#' are the same in each class and considers the test statistic as an variable
+#' importance measure: if the location parameters do not differ in at least one
+#' case, i.e., the null hypothesis cannot be rejected, there is little evidence
+#' that the corresponding feature is suitable for classification.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
 makeFilter(
   name = "kruskal.test",
   desc = "Kruskal Test for binary and multiclass classification tasks",
@@ -367,6 +537,12 @@ makeFilter(
   }
 )
 
+#' Simple filter based on the variance of the features indepentent of each other.
+#' Features with higher variance are considered more important than features with
+#' low importance.
+#'
+#' @rdname makeFilter
+#' @name makeFilter
 makeFilter(
   name = "variance",
   desc = "A simple variance filter",
@@ -386,7 +562,7 @@ makeFilter(
 #' \code{imp.learner}, a [\code{\link{Learner}} or \code{character(1)}] which specifies the learner
 #' to use when computing the permutation importance, \code{contrast}, a \code{function} which takes two
 #' numeric vectors and returns one (default is the difference), \code{aggregation}, a \code{function} which
-#' takes a \code{numeric} and returns a \code{numeric(1)} (default is the mean), \code{nperm},
+#' takes a \code{numeric} and returns a \code{numeric(1)} (default is the mean), \code{nmc},
 #' an \code{integer(1)}, and \code{replace}, a \code{logical(1)} which determines whether the feature being
 #' permuted is sampled with or without replacement.
 #'
@@ -397,40 +573,15 @@ makeFilter(
   desc = "Aggregated difference between feature permuted and unpermuted predictions",
   pkg = character(0L),
   supported.tasks = c("classif", "regr", "surv"),
-  supported.features = c("numerics", "factors"),
+  supported.features = c("numerics", "factors", "ordered"),
   fun = function(task, imp.learner, measure, contrast = function(x, y) x - y,
-                 aggregation = mean, nperm = 1, replace = FALSE, nselect) {
-    imp.learner = checkLearner(imp.learner)
-    measure = checkMeasures(measure, imp.learner)
-    if (getTaskType(task) != imp.learner$type)
-      stopf("Expected task of type '%s', not '%s'", getTaskType(task), imp.learner$type)
-    if (length(measure) != 1L)
-      stop("Exactly one measure must be provided")
-    assertCount(nperm)
-    test.contrast = contrast(1, 1)
-    assert(is.numeric(test.contrast) & length(test.contrast) == 1L)
-    test.aggregation = aggregation(1:2)
-    assert(is.numeric(test.aggregation) & length(test.aggregation) == 1L)
-
-    doPermutationImportance = function(task, imp.learner, measure, contrast, i) {
-      fit = train(imp.learner, task)
-      pred = predict(fit, task = task)
-      data = getTaskData(task)
-
-      sapply(getTaskFeatureNames(task), function(x) {
-        data[[x]] = sample(data[[x]], length(data[[x]]), replace)
-        pred.permuted = predict(fit, newdata = data)
-        perf = performance(pred, measure)
-        perf.permuted = performance(pred.permuted, measure)
-        contrast(perf.permuted, perf)
-      }, USE.NAMES = FALSE)
-    }
-
-    args = list(task = task, imp.learner = imp.learner, measure = measure, contrast = contrast)
-    out = parallelMap::parallelMap(doPermutationImportance, seq_len(nperm), more.args = args)
-    out = do.call("rbind", out)
-    out = apply(out, 2, aggregation)
-    names(out) = getTaskFeatureNames(task)
-    return(out)
+                 aggregation = mean, nmc = 50L, replace = FALSE, nselect) {
+    imp = generateFeatureImportanceData(task, "permutation.importance",
+      imp.learner, interaction = FALSE, measure = measure,
+      contrast = contrast, aggregation = aggregation,
+      nmc = nmc, replace = replace, local = FALSE)
+    imp = as.numeric(imp$res)
+    names(imp) = getTaskFeatureNames(task)
+    return(imp)
   }
 )
