@@ -13,10 +13,10 @@
 #' @family wrapper
 #' @template ret_learner
 makeImputeWrapper = function(learner, classes = list(), cols = list(),
-  dummy.classes = character(0L), dummy.cols = character(0L), dummy.type = "factor", impute.new.levels = TRUE, recode.factor.levels = TRUE) {
+  dummy.classes = character(0L), dummy.cols = character(0L), dummy.type = "factor", force.dummies = FALSE, impute.new.levels = TRUE, recode.factor.levels = TRUE) {
   learner = checkLearner(learner)
   args = list(classes = classes, cols = cols,
-    dummy.classes = dummy.classes, dummy.cols = dummy.cols, dummy.type = dummy.type,
+    dummy.classes = dummy.classes, dummy.cols = dummy.cols, dummy.type = dummy.type, force.dummies = force.dummies,
     impute.new.levels = impute.new.levels, recode.factor.levels = recode.factor.levels)
   rm(list = names(args))
 
@@ -29,6 +29,7 @@ makeImputeWrapper = function(learner, classes = list(), cols = list(),
   }
 
   lrn = makePreprocWrapper(learner, trainfun, predictfun, par.vals = args)
+  lrn$id = stri_replace(lrn$id, replacement = ".imputed", regex = "[.]preproc$")
   addClasses(lrn, "ImputeWrapper")
 }
 
