@@ -14,8 +14,7 @@ makeRLearner.classif.LiblineaRL1L2SVC = function() {
     properties = c("twoclass", "multiclass", "numerics", "class.weights"),
     class.weights.param = "wi",
     name = "L1-Regularized L2-Loss Support Vector Classification",
-    short.name = "liblinl1l2svc",
-    note = ""
+    short.name = "liblinl1l2svc"
   )
 }
 
