@@ -5,11 +5,11 @@ makeRLearner.classif.glmnet = function() {
     package = "glmnet",
     par.set = makeParamSet(
       makeNumericLearnerParam(id = "alpha", default = 1, lower = 0, upper = 1),
-      makeNumericLearnerParam(id = "s", default = 0.01, lower = 0, upper = 1, when = "predict"),
+      makeNumericLearnerParam(id = "s", lower = 0, when = "predict"),
       makeLogicalLearnerParam(id = "exact", default = FALSE, when = "predict"),
       makeIntegerLearnerParam(id = "nlambda", default = 100L, lower = 1L),
       makeNumericLearnerParam(id = "lambda.min.ratio", lower = 0, upper = 1),
-      makeNumericVectorLearnerParam(id = "lambda"),
+      makeNumericVectorLearnerParam(id = "lambda", lower = 0),
       makeLogicalLearnerParam(id = "standardize", default = TRUE),
       makeLogicalLearnerParam(id = "intercept", default = TRUE),
       makeNumericLearnerParam(id = "thresh", default = 1e-07, lower = 0),
@@ -37,7 +37,10 @@ makeRLearner.classif.glmnet = function() {
     par.vals = list(s = 0.01),
     name = "GLM with Lasso or Elasticnet Regularization",
     short.name = "glmnet",
-    note = "The family parameter is set to `binomial` for two-class problems and to `multinomial` otherwise. Factors automatically get converted to dummy columns, ordered factors to integer."
+    note = "The family parameter is set to `binomial` for two-class problems and to `multinomial` otherwise.
+      Factors automatically get converted to dummy columns, ordered factors to integer.
+      Parameter `s` (value of the regularization parameter used for predictions) is set to `0.1` by default,
+      but needs to be tuned by the user."
   )
 }
 
@@ -68,7 +71,7 @@ trainLearner.classif.glmnet = function(.learner, .task, .subset, .weights = NULL
 predictLearner.classif.glmnet = function(.learner, .model, .newdata, ...) {
   info = getTrainingInfo(.model)
   .newdata = as.matrix(fixDataForLearner(.newdata, info))
-  if(.learner$predict.type == "prob") {
+  if (.learner$predict.type == "prob") {
     p = predict(.model$learner.model, newx = .newdata, type = "response", ...)
     td = .model$task.desc
     if (length(td$class.levels) == 2L) {
