@@ -13,8 +13,7 @@ makeRLearner.classif.knn = function() {
     # knn also cannot handle factors in features apparantly
     properties = c("twoclass", "multiclass", "numerics"),
     name = "k-Nearest Neighbor",
-    short.name = "knn",
-    note = ""
+    short.name = "knn"
   )
 }
 
