@@ -14,7 +14,7 @@ makeRLearner.classif.logreg = function() {
 #' @export
 trainLearner.classif.logreg = function(.learner, .task, .subset, .weights = NULL,  ...) {
   f = getTaskFormula(.task)
-  stats::glm(f, data = getTaskData(.task, .subset), model = FALSE, family = "binomial", ...)
+  stats::glm(f, data = getTaskData(.task, .subset), model = FALSE, family = "binomial", weights = .weights, ...)
 }
 
 #' @export
