@@ -8,8 +8,7 @@ makeRLearner.classif.plsdaCaret = function() {
     ),
     properties = c("numerics", "prob", "twoclass"),
     name = "Partial Least Squares (PLS) Discriminant Analysis",
-    short.name = "plsdacaret",
-    note = ""
+    short.name = "plsdacaret"
   )
 }
 
