@@ -7,6 +7,7 @@ makeRLearner.regr.avNNet = function() {
       makeIntegerLearnerParam(id = "repeats", default = 5L, lower = 1L),
       makeLogicalLearnerParam(id = "bag", default = FALSE),
       makeIntegerLearnerParam(id = "size", default = 3L, lower = 0L),
+      # FIXME size seems to have no default in nnet(), if it has 1 par.vals is redundant
       makeIntegerLearnerParam(id = "maxit", default = 100L, lower = 1L),
       makeLogicalLearnerParam(id = "linout", default = FALSE, requires = quote(entropy==FALSE && softmax==FALSE && censored==FALSE)),
       makeLogicalLearnerParam(id = "entropy", default = FALSE, requires = quote(linout==FALSE && softmax==FALSE && censored==FALSE)),
@@ -21,7 +22,7 @@ makeRLearner.regr.avNNet = function() {
       makeNumericLearnerParam(id = "abstoll", default = 1.0e-4),
       makeNumericLearnerParam(id = "reltoll", default = 1.0e-8)
     ),
-    par.vals = list(size = 3L),
+    par.vals = list(size = 3L, linout = TRUE),
     properties = c("numerics", "factors", "weights"),
     name = "Neural Network",
     short.name = "avNNet",
@@ -35,11 +36,11 @@ trainLearner.regr.avNNet = function(.learner, .task, .subset, .weights = NULL, .
   bag = FALSE
   
   nms = names(.learner$par.vals)
-  ind = grep('repeats',nms)
-  if (length(ind)>0)
+  ind = stri_detect_regex(nms, "repeats")
+  if (sum(ind)>0)
     repeats = .learner$par.vals[[ind]]
-  ind = grep('bag',nms)
-  if (length(ind)>0)
+  ind = stri_detect_regex(nms, "bag")
+  if (sum(ind)>0)
     bag = .learner$par.vals[[ind]]
   
   assertInt(repeats, lower = 1)
@@ -57,10 +58,10 @@ trainLearner.regr.avNNet = function(.learner, .task, .subset, .weights = NULL, .
     assertInteger(ind, len = nrow(dat))
     if (is.null(.weights)) {
       f = getTaskFormula(.task)
-      nets[[i]] = nnet::nnet(f, data = dat[ind,], linout = TRUE, ...)
+      nets[[i]] = nnet::nnet(f, data = dat[ind,], ...)
     } else {
       f = getTaskFormula(.task)
-      nets[[i]] = nnet::nnet(f, data = dat[ind,], linout = TRUE, weights = .weights, ...)
+      nets[[i]] = nnet::nnet(f, data = dat[ind,], weights = .weights, ...)
     }
   }
   return(nets)
