@@ -12,7 +12,13 @@ makeRLearner.regr.blm = function() {
         default = c(1000, 4000, 3), lower = 0), 
       makeIntegerLearnerParam(id = "R", default = 1, lower = 1), 
       makeLogicalLearnerParam(id = "m0r1", default = TRUE),
-      makeUntypedLearnerParam(id = "itemps", default = NULL)
+      makeUntypedLearnerParam(id = "itemps", default = NULL),
+      makeLogicalLearnerParam(id = "krige", default = TRUE),
+      makeLogicalLearnerParam(id = "zcov", default = FALSE),
+      makeLogicalLearnerParam(id = "Ds2x", default = FALSE),
+      makeLogicalLearnerParam(id = "improv", default = FALSE),
+      makeLogicalLearnerParam(id = "trace", default = FALSE, tunable = FALSE),
+      makeIntegerLearnerParam(id = "verb", default = 1L, lower = 0L, upper = 4L, tunable = FALSE)
     ),
     properties = c("numerics", "se"),
     name = "Bayesian Linear Model",
