@@ -22,8 +22,7 @@ makeRLearner.regr.brnn = function() {
     ),
     properties = c("numerics", "factors"),
     name = "Bayesian regularization for feed-forward neural networks",
-    short.name = "brnn",
-    note = ""
+    short.name = "brnn"
   )
 }
 
