@@ -18,10 +18,16 @@ makeRLearner.regr.btgpllm = function() {
         default = c(2000, 7000, 2), lower = 0), 
       makeIntegerLearnerParam(id = "R", default = 1, lower = 1), 
       makeLogicalLearnerParam(id = "m0r1", default = TRUE),
-      makeUntypedLearnerParam(id = "itemps", default = NULL),
       makeLogicalLearnerParam(id = "linburn", default = FALSE),
+      makeUntypedLearnerParam(id = "itemps", default = NULL),
+      makeLogicalLearnerParam(id = "krige", default = TRUE),
+      makeLogicalLearnerParam(id = "zcov", default = FALSE),
+      makeLogicalLearnerParam(id = "Ds2x", default = FALSE),
+      makeLogicalLearnerParam(id = "improv", default = FALSE),
       makeNumericLearnerParam(id = "nu", default = 1.5, 
-        requires = quote(corr == "matern"))
+        requires = quote(corr == "matern")),
+      makeLogicalLearnerParam(id = "trace", default = FALSE, tunable = FALSE),
+      makeIntegerLearnerParam(id = "verb", default = 1L, lower = 0L, upper = 4L, tunable = FALSE)      
     ),
     properties = c("numerics", "se", "factors"),
     name = "Bayesian Treed Gaussian Process with jumps to the Limiting Linear Model",
