@@ -10,22 +10,19 @@ makeRLearner.regr.cforest = function() {
       makeLogicalLearnerParam(id = "trace", default = FALSE, tunable = FALSE),
       makeNumericLearnerParam(id = "fraction", lower = 0, upper = 1, default = 0.632),
       makeDiscreteLearnerParam(id = "teststat", values = c("quad", "max"), default = 'quad'),
-      makeLogicalLearnerParam(id = "pvalue", default = TRUE),
       makeDiscreteLearnerParam(id = "testtype",
         values = c("Bonferroni", "MonteCarlo", "Univariate", "Teststatistic"),
         default = 'Univariate'),
       makeNumericLearnerParam(id = "mincriterion", lower = 0, default = 0),
-      makeNumericLearnerParam(id = "minprob", lower = 0, default = 0.01),
       makeIntegerLearnerParam(id = "minsplit", lower = 1L, default = 20L),
       makeIntegerLearnerParam(id = "minbucket", lower = 1L, default = 7L),
       makeLogicalLearnerParam(id = "stump", default = FALSE),
-      makeLogicalLearnerParam(id = "randomsplits", default = TRUE),
       makeIntegerLearnerParam(id = "nresample", lower = 1L, default = 9999L),
       makeIntegerLearnerParam(id = "maxsurrogate", lower = 0L, default = 0L),
       makeIntegerLearnerParam(id = "maxdepth", lower = 0L, default = 0L),
       makeLogicalLearnerParam(id = "savesplitstats", default = FALSE, tunable = FALSE)
     ),
-    properties = c("numerics", "factors", "ordered", "weights", "missings"),
+    properties = c("numerics", "factors", "ordered", "weights", "missings", "featimp"),
     par.vals = list(),
     name = "Random Forest Based on Conditional Inference Trees",
     short.name = "cforest",
@@ -35,9 +32,9 @@ makeRLearner.regr.cforest = function() {
 
 #' @export
 trainLearner.regr.cforest = function(.learner, .task, .subset, .weights = NULL,
-                                     ntree, mtry, replace, fraction, trace, pvalue,
-                                     teststat, testtype, mincriterion, minprob,
-                                     minsplit, minbucket, stump, randomsplits,
+                                     ntree, mtry, replace, fraction, trace,
+                                     teststat, testtype, mincriterion,
+                                     minsplit, minbucket, stump,
                                      nresample, maxsurrogate, maxdepth,
                                      savesplitstats,...) {
   f = getTaskFormula(.task)
@@ -49,8 +46,8 @@ trainLearner.regr.cforest = function(.learner, .task, .subset, .weights = NULL,
   if (missing(replace)) replace = defaults$replace
   if (missing(fraction)) fraction = defaults$fraction
   ctrl = learnerArgsToControl(party::cforest_control, ntree, mtry, replace, fraction,
-                              trace, pvalue, teststat, testtype, mincriterion,
-                              minprob, minsplit, minbucket, stump, randomsplits,
+                              trace, teststat, testtype, mincriterion,
+                              minsplit, minbucket, stump,
                               nresample, maxsurrogate, maxdepth, savesplitstats)
   party::cforest(f, data = d, controls = ctrl, weights = .weights, ...)
 }
@@ -59,3 +56,8 @@ trainLearner.regr.cforest = function(.learner, .task, .subset, .weights = NULL,
 predictLearner.regr.cforest = function(.learner, .model, .newdata, ...) {
   as.vector(predict(.model$learner.model, newdata = .newdata, ...))
 }
+
+#' @export
+getFeatureImportanceLearner.regr.cforest = function(.learner, .model, ...) {
+  getFeatureImportanceLearner.classif.cforest(.learner, .model, auc = FALSE, ...)
+}
