@@ -42,7 +42,7 @@ makeRLearner.surv.randomForestSRC = function() {
       makeLogicalLearnerParam(id = "tree.err", default = FALSE, tunable = FALSE)
     ),
     par.vals = list(na.action = "na.impute"),
-    properties = c("missings", "numerics", "factors", "ordered", "rcens", "weights"),
+    properties = c("missings", "numerics", "factors", "ordered", "rcens", "weights", "featimp"),
     name = "Random Forest",
     short.name = "rfsrc",
     note = '`na.action` has been set to `"na.impute"` by default to allow missing data support.'
@@ -59,3 +59,8 @@ trainLearner.surv.randomForestSRC = function(.learner, .task, .subset, .weights
 predictLearner.surv.randomForestSRC = function(.learner, .model, .newdata, ...) {
   predict(.model$learner.model, newdata = .newdata, membership = FALSE, ...)$predicted
 }
+
+#' @export
+getFeatureImportanceLearner.surv.randomForestSRC = function(.learner, .model, ...) {
+  getFeatureImportanceLearner.regr.randomForestSRC(.learner, .model, ...)
+}
