@@ -38,7 +38,7 @@ evalOptimizationState = function(learner, task, resampling, measures, par.set, b
     prev.stage = log.fun(learner, task, resampling, measures, par.set, control, opt.path, dob,
       state, NA_real_, remove.nas, stage = 1L)
   if (set.pars.ok) {
-    exec.time = system.time({
+    exec.time = measureTime({
       r = resample(learner2, task, resampling, measures = measures, show.info = FALSE)
     })
 
@@ -61,7 +61,6 @@ evalOptimizationState = function(learner, task, resampling, measures, par.set, b
     notna = !is.na(errmsgs)
     if (any(notna))
       errmsg = errmsgs[notna][1L]
-    exec.time = exec.time[3L]
   } else {
     # we still need to define a non-NULL threshold, if tuning it was requested
     if (control$tune.threshold)
@@ -98,14 +97,7 @@ evalOptimizationStates = function(learner, task, resampling, measures, par.set,
   # add stuff to opt.path
   for (i in seq_len(n)) {
     res = res.list[[i]]
-    if (control$tune.threshold) {
-      # add class names to threshold, if longer than 1
-      extra = as.list(res$threshold)
-      names(extra) = stri_paste("threshold", ifelse(length(extra) > 1L, ".", ""), 
-                                names(extra), ignore_null = TRUE)
-    } else {
-      extra = NULL
-    }
+    extra = getTuneThresholdExtra(control, res)
     addOptPathEl(opt.path, x = as.list(states[[i]]), y = res$y, exec.time = res$exec.time,
       error.message = res$errmsg, dob = dobs[i], eol = eols[i], check.feasible = TRUE,
       extra = extra)
