@@ -1,14 +1,15 @@
-
 #' @title Perform a posthoc Friedman-Nemenyi test.
 #'
 #' @description
 #' Performs a \code{\link[PMCMR]{posthoc.friedman.nemenyi.test}} for a
 #' \code{\link{BenchmarkResult}} and a selected measure.
-#' This means \code{all pairwise comparisons} of \code{learners} are performed.
+#' This means \emph{all pairwise comparisons} of \code{learners} are performed.
 #' The null hypothesis of the post hoc test is that each pair of learners is equal.
 #' If the null hypothesis of the included ad hoc \code{\link[stats]{friedman.test}}
-#' can be rejected a \code{pairwise.htest} is returned. If not, the function returns the
-#' corresponding \link[stats]{friedman.test}
+#' can be rejected an object of class \code{pairwise.htest} is returned. If not, the function returns the
+#' corresponding \link[stats]{friedman.test}.
+#' Note that benchmark results for at least two learners on at least two tasks
+#' are required.
 #'
 #' @template arg_bmr
 #' @template arg_measure
@@ -34,8 +35,10 @@ friedmanPostHocTestBMR = function(bmr, measure = NULL, p.value = 0.05, aggregati
   measure = checkBMRMeasure(measure, bmr)
   n.learners = length(bmr$learners)
   if (n.learners < 2)
-    message("Only one Learner to compare")
+    stop("Benchmark results for at least two learners are required")
   n.tasks = length(bmr$results)
+  if (n.tasks < 2)
+    stop("Benchmark results for at least two tasks are required")
   
   # aggregate over iterations
   if (aggregation == "mean") {
