@@ -11,7 +11,7 @@
 #' @template arg_task
 #' @param method [\code{character}]\cr
 #'   Filter method(s), see above.
-#'   Default is \dQuote{rf.importance}.
+#'   Default is \dQuote{randomForestSRC.rfsrc}.
 #' @param nselect [\code{integer(1)}]\cr
 #'   Number of scores to request. Scores are getting calculated for all features per default.
 #' @param ... [any]\cr
@@ -32,7 +32,7 @@
 #'                   the feature importance values.
 #'     }}
 #' @export
-generateFilterValuesData = function(task, method = "rf.importance", nselect = getTaskNFeats(task), ..., more.args = list()) {
+generateFilterValuesData = function(task, method = "randomForestSRC.rfsrc", nselect = getTaskNFeats(task), ..., more.args = list()) {
   assert(checkClass(task, "ClassifTask"), checkClass(task, "RegrTask"), checkClass(task, "SurvTask"))
   assertSubset(method, choices = ls(.FilterRegister), empty.ok = FALSE)
   td = getTaskDescription(task)
@@ -41,15 +41,15 @@ generateFilterValuesData = function(task, method = "rf.importance", nselect = ge
     lapply(filter, function(x) requirePackages(x$pkg, why = "generateFilterValuesData", default.method = "load"))
   check_task = sapply(filter, function(x) td$type %nin% x$supported.tasks)
   if (any(check_task))
-    stopf("Filter(s) '%s' not campatible with task of type '%s'",
-          stri_paste(method[check_task], collapse = ", ", sep = " "), td$type)
+    stopf("Filter(s) %s not compatible with task of type '%s'",
+          stri_paste("'", method[check_task], "'", collapse = ", "), td$type)
 
-  check_feat = lapply(filter, function(x) setdiff(names(td$nfeat[td$n.feat > 0L]), x$supported.features))
+  check_feat = lapply(filter, function(x) setdiff(names(td$n.feat[td$n.feat > 0L]), x$supported.features))
   check_length = sapply(check_feat, length) > 0L
   if (any(check_length)) {
-    stopf("Filter(s) '%s' not compatible with features of type '%s' respectively.",
-          method[check_length],
-          stri_paste(sapply(check_feat[check_length], function(x) stri_paste(x, collapse = ", ", sep = " ")), collapse = ", and", sep = " "))
+    stopf("Filter(s) %s not compatible with features of type %s respectively",
+          stri_paste("'", method[check_length], "'", collapse = ", "),
+          stri_paste(sapply(check_feat[check_length], function(x) stri_paste("'", x, "'", collapse = ", ")), collapse = ", and "))
   }
   assertCount(nselect)
   assertList(more.args, names = "unique", max.len = length(method))
@@ -73,7 +73,7 @@ generateFilterValuesData = function(task, method = "rf.importance", nselect = ge
     x = do.call(x$fun, c(list(task = task, nselect = nselect), more.args[[x$name]]))
     missing.score = setdiff(fn, names(x))
     x[missing.score] = NA_real_
-    x[match(names(x), fn)]
+    x[match(fn, names(x))]
   })
 
   fval = do.call(cbind, fval)
@@ -90,7 +90,7 @@ generateFilterValuesData = function(task, method = "rf.importance", nselect = ge
 print.FilterValues = function(x, ...) {
   catf("FilterValues:")
   catf("Task: %s", x$task.desc$id)
-  print(head(x$data))
+  printHead(x$data)
 }
 #' @title Calculates feature filter values.
 #'
@@ -104,7 +104,7 @@ print.FilterValues = function(x, ...) {
 #' @template arg_task
 #' @param method [\code{character(1)}]\cr
 #'   Filter method, see above.
-#'   Default is \dQuote{rf.importance}.
+#'   Default is \dQuote{randomForestSRC.rfsrc}.
 #' @param nselect [\code{integer(1)}]\cr
 #'   Number of scores to request. Scores are getting calculated for all features per default.
 #' @param ... [any]\cr
@@ -113,8 +113,8 @@ print.FilterValues = function(x, ...) {
 #' @note \code{getFilterValues} is deprecated in favor of \code{\link{generateFilterValuesData}}.
 #' @family filter
 #' @export
-getFilterValues = function(task, method = "rf.importance", nselect = getTaskNFeats(task), ...) {
-  warning("getFilterValues is deprecated. Use generateFilterValuesData.")
+getFilterValues = function(task, method = "randomForestSRC.rfsrc", nselect = getTaskNFeats(task), ...) {
+  .Deprecated("generateFilterValuesData")
   assertChoice(method, choices = ls(.FilterRegister))
   out = generateFilterValuesData(task, method, nselect, ...)
   colnames(out$data)[3] = "val"
@@ -126,8 +126,8 @@ getFilterValues = function(task, method = "rf.importance", nselect = getTaskNFea
 }
 #' Plot filter values using ggplot2.
 #'
-#' @family plot
 #' @family filter
+#' @family generate_plot_data
 #'
 #' @param fvalues [\code{\link{FilterValues}}]\cr
 #'   Filter values.
@@ -159,7 +159,7 @@ plotFilterValues = function(fvalues, sort = "dec", n.show = 20L, feat.type.cols
   data = fvalues$data
   methods = colnames(data[, -which(colnames(data) %in% c("name", "type")), drop = FALSE])
   n.show = min(n.show, max(sapply(methods, function(x) sum(!is.na(data[[x]])))))
-  data = reshape2::melt(data, id.vars = c("name", "type"), variable = "method")
+  data = melt(as.data.table(data), id.vars = c("name", "type"), variable = "method")
 
   if (sort != "none")
     data = do.call(rbind, lapply(methods, function(x)
@@ -207,12 +207,13 @@ plotFilterValues = function(fvalues, sort = "dec", n.show = 20L, feat.type.cols
 #' plotFilterValuesGGVIS(fv)
 #' }
 plotFilterValuesGGVIS = function(fvalues, feat.type.cols = FALSE) {
+  requirePackages("_ggvis")
   assertClass(fvalues, classes = "FilterValues")
   if (!(is.null(fvalues$method)))
     stop("fvalues must be generated by generateFilterValuesData, not getFilterValues, which is deprecated.")
 
   data = fvalues$data
-  data = reshape2::melt(data, id.vars = c("name", "type"), variable = "method")
+  data = setDF(melt(as.data.table(data), id.vars = c("name", "type"), variable = "method"))
 
   create_plot = function(data, feat.type.cols) {
     if (feat.type.cols)
@@ -239,6 +240,7 @@ plotFilterValuesGGVIS = function(fvalues, feat.type.cols = FALSE) {
     data
   }
 
+  requirePackages("_shiny")
   header = shiny::headerPanel(sprintf("%s (%i features)", fvalues$task.desc$id, sum(fvalues$task.desc$n.feat)))
   method_input = shiny::selectInput("level_variable", "choose a filter method",
                                     unique(levels(data[["method"]])))
