@@ -46,6 +46,7 @@
 generateLearningCurveData = function(learners, task, resampling = NULL,
   percs = seq(0.1, 1, by = 0.1), measures, stratify = FALSE, show.info = getMlrOption("show.info"))  {
 
+  learners = ensureVector(learners, 1, "Learner")
   learners = lapply(learners, checkLearner)
   assertClass(task, "Task")
   assertNumeric(percs, lower = 0L, upper = 1L, min.len = 2L, any.missing = FALSE)
@@ -57,16 +58,14 @@ generateLearningCurveData = function(learners, task, resampling = NULL,
   else
     assert(checkClass(resampling, "ResampleDesc"), checkClass(resampling, "ResampleInstance"))
 
-  perc.ids = seq_along(percs)
-
   # create downsampled versions for all learners
   lrnds1 = lapply(learners, function(lrn) {
-    lapply(perc.ids, function(p.id) {
+    lapply(seq_along(percs), function(p.id) {
       perc = percs[p.id]
       dsw = makeDownsampleWrapper(learner = lrn, dw.perc = perc, dw.stratify = stratify)
       list(
         lrn.id = lrn$id,
-        lrn = setId(dsw, stri_paste(lrn$id, ".", p.id)),
+        lrn = setLearnerId(dsw, stri_paste(lrn$id, ".", p.id)),
         perc = perc
       )
     })
@@ -97,7 +96,7 @@ print.LearningCurveData = function(x, ...) {
   catf("LearningCurveData:")
   catf("Task: %s", x$task$task.desc$id)
   catf("Measures: %s", collapse(extractSubList(x$measures, "name")))
-  print(head(x$data))
+  printHead(x$data)
 }
 #' @title Plot learning curve data using ggplot2.
 #'
@@ -134,9 +133,7 @@ plotLearningCurve = function(obj, facet = "measure", pretty.names = TRUE,
       names(obj$measures), mnames)
   }
 
-  data = reshape2::melt(obj$data,
-    id.vars = c("learner", "percentage"),
-    variable.name = "measure", value.name = "performance")
+  data = melt(as.data.table(obj$data), id.vars = c("learner", "percentage"), variable.name = "measure", value.name = "performance")
   nlearn = length(unique(data$learner))
   nmeas = length(unique(data$measure))
 
@@ -181,6 +178,7 @@ plotLearningCurve = function(obj, facet = "measure", pretty.names = TRUE,
 #' @template ret_ggv
 #' @export
 plotLearningCurveGGVIS = function(obj, interaction = "measure", pretty.names = TRUE) {
+  requirePackages("_ggvis")
   assertClass(obj, "LearningCurveData")
   mappings = c("measure", "learner")
   assertChoice(interaction, mappings)
@@ -194,9 +192,7 @@ plotLearningCurveGGVIS = function(obj, interaction = "measure", pretty.names = T
                                    mnames)
   }
 
-  data = reshape2::melt(obj$data,
-                        id.vars = c("learner", "percentage"),
-                        variable.name = "measure", value.name = "performance")
+  data = setDF(melt(as.data.table(obj$data), id.vars = c("learner", "percentage"), variable.name = "measure", value.name = "performance"))
   nmeas = length(unique(data$measure))
   nlearn = length(unique(data$learner))
 
@@ -220,6 +216,7 @@ plotLearningCurveGGVIS = function(obj, interaction = "measure", pretty.names = T
   }
 
   if (!is.null(interaction)) {
+    requirePackages("_shiny")
     ui = shiny::shinyUI(
         shiny::pageWithSidebar(
             shiny::headerPanel("learning curve"),
