@@ -88,7 +88,7 @@ generateThreshVsPerfData.list = function(obj, measures, gridsize = 100L, aggrega
     out = out[[1L]]
     colnames(out)[!colnames(out) %in% c("iter", "threshold", "learner")] = mids
   } else {
-    out = plyr::ldply(out, .id = "learner")
+    out = setDF(rbindlist(lapply(out, as.data.table), fill = TRUE, idcol = "learner"))
     colnames(out)[!colnames(out) %in% c("iter", "threshold", "learner")] = mids
   }
 
@@ -108,6 +108,11 @@ generateThreshVsPerfData.list = function(obj, measures, gridsize = 100L, aggrega
 #'
 #' @param obj [\code{ThreshVsPerfData}]\cr
 #'   Result of \code{\link{generateThreshVsPerfData}}.
+#' @param measures [\code{\link{Measure}} | list of \code{\link{Measure}}]\cr
+#'   Performance measure(s) to plot.
+#'   Must be a subset of those used in \code{\link{generateThreshVsPerfData}}.
+#'   Default is all the measures stored in \code{obj} generated by
+#'   \code{\link{generateThreshVsPerfData}}.
 #' @param facet [\code{character(1)}]\cr
 #'   Selects \dQuote{measure} or \dQuote{learner} to be the facetting variable.
 #'   The variable mapped to \code{facet} must have more than one unique value, otherwise it will
@@ -128,29 +133,33 @@ generateThreshVsPerfData.list = function(obj, measures, gridsize = 100L, aggrega
 #' pred = predict(mod, sonar.task)
 #' pvs = generateThreshVsPerfData(pred, list(acc, setAggregation(acc, train.mean)))
 #' plotThreshVsPerf(pvs)
-plotThreshVsPerf = function(obj, facet = "measure", mark.th = NA_real_,
+plotThreshVsPerf = function(obj, measures = obj$measures,
+  facet = "measure", mark.th = NA_real_,
   pretty.names = TRUE, facet.wrap.nrow = NULL, facet.wrap.ncol = NULL) {
+
   assertClass(obj, classes = "ThreshVsPerfData")
   mappings = c("measure", "learner")
   assertChoice(facet, mappings)
   color = mappings[mappings != facet]
-
-  if (pretty.names) {
-    mnames = replaceDupeMeasureNames(obj$measures, "name")
-    colnames(obj$data) = mapValues(colnames(obj$data), names(obj$measures), mnames)
-  } else {
-    mnames = names(obj$measures)
-  }
+  measures = checkMeasures(measures, obj)
+  checkSubset(extractSubList(measures, "id"), extractSubList(obj$measures, "id"))
+  mids = replaceDupeMeasureNames(measures, "id")
+  names(measures) = mids
 
   id.vars = "threshold"
   resamp = "iter" %in% colnames(obj$data)
   if (resamp) id.vars = c(id.vars, "iter")
   if ("learner" %in% colnames(obj$data)) id.vars = c(id.vars, "learner")
+  obj$data = obj$data[, c(id.vars, names(measures))]
 
-  data = reshape2::melt(obj$data,
-              measure.vars = mnames,
-              variable.name = "measure", value.name = "performance",
-              id.vars = id.vars)
+  if (pretty.names) {
+    mnames = replaceDupeMeasureNames(measures, "name")
+    colnames(obj$data) = mapValues(colnames(obj$data), names(measures), mnames)
+  } else {
+    mnames = names(measures)
+  }
+
+  data = setDF(melt(as.data.table(obj$data), measure.vars = mnames, variable.name = "measure", value.name = "performance", id.vars = id.vars))
   if (!is.null(data$learner))
     nlearn = length(unique(data$learner))
   else
@@ -223,6 +232,7 @@ plotThreshVsPerf = function(obj, facet = "measure", mark.th = NA_real_,
 #' plotThreshVsPerfGGVIS(pvs)
 #' }
 plotThreshVsPerfGGVIS = function(obj, interaction = "measure", mark.th = NA_real_, pretty.names = TRUE) {
+  requirePackages("_ggvis")
   assertClass(obj, classes = "ThreshVsPerfData")
   mappings = c("measure", "learner")
   assertChoice(interaction, mappings)
@@ -242,10 +252,7 @@ plotThreshVsPerfGGVIS = function(obj, interaction = "measure", mark.th = NA_real
   if (resamp) id.vars = c(id.vars, "iter")
   if ("learner" %in% colnames(obj$data)) id.vars = c(id.vars, "learner")
 
-  data = reshape2::melt(obj$data,
-              measure.vars = mnames,
-              variable.name = "measure", value.name = "performance",
-              id.vars = id.vars)
+  data = setDF(data.table(melt(as.data.table(obj$data), measure.vars = mnames, variable.name = "measure", value.name = "performance", id.vars = id.vars)))
   nmeas = length(unique(data$measure))
 
   if (!is.null(data$learner))
@@ -296,6 +303,7 @@ plotThreshVsPerfGGVIS = function(obj, interaction = "measure", mark.th = NA_real
   }
 
   if (!is.null(interaction)) {
+    requirePackages("_shiny")
     ui = shiny::shinyUI(
       shiny::pageWithSidebar(
         shiny::headerPanel("Threshold vs. Performance"),
