@@ -16,8 +16,10 @@ measureAggrPrettyName = function(measure) {
   stri_paste(measure$name, measure$aggr$name, sep = ": ")
 }
 
-perfsToString = function(y) {
-  stri_paste(stri_paste(names(y), "=", formatC(y, digits = 3L), sep = ""), 
+# convert a named numvec of perf values (think 'aggr' from resample) into flat string
+# ala <name><sep><value>,...,<name><sep><value>
+perfsToString = function(y, sep = "=") {
+  stri_paste(stri_paste(names(y), "=", formatC(y, digits = 3L), sep = ""),
              collapse = ",", sep = " ")
 }
 
@@ -54,6 +56,13 @@ getSupportedTaskTypes = function() {
   c("classif", "regr", "surv", "costsens", "cluster", "multilabel")
 }
 
+# Maybe move to BBmisc at some point
+measureTime = function(expr, ee = parent.frame()) {
+  before = proc.time()[[3L]]
+  force(expr)
+  proc.time()[[3L]] - before
+}
+
 # find duplicate measure names or ids and paste together those
 # with the associated aggregation ids or names
 replaceDupeMeasureNames = function(measures, x = "id") {
