@@ -8,8 +8,11 @@
 #'   Optional list of named (hyper)parameter settings. The arguments in
 #'   \code{...} take precedence over values in this list.
 #' @template ret_learner
+#' @note If a named (hyper)parameter can't be found for the given learner, the 3
+#' closest (hyper)parameter names will be output in case the user mistyped.
 #' @export
 #' @family learner
+#' @importFrom utils adist
 #' @examples
 #' cl1 = makeLearner("classif.ksvm", sigma = 1)
 #' cl2 = setHyperPars(cl1, sigma = 10, par.vals = list(C = 2))
@@ -36,21 +39,32 @@ setHyperPars2 = function(learner, par.vals) {
 
 #' @export
 setHyperPars2.Learner = function(learner, par.vals) {
+  if (length(par.vals) == 0L)
+    return(learner)
+
   ns = names(par.vals)
-  # ensure that even the empty list is named, we had problems here, see #759
-  if (is.null(ns) && is.null(names(learner$par.vals))) {
-    names(learner$par.vals) = character(0)
-  }
   pars = learner$par.set$pars
-  on.par.without.desc = coalesce(learner$config$on.par.without.desc, getMlrOptions()$on.par.without.desc)
-  on.par.out.of.bounds = coalesce(learner$config$on.par.out.of.bounds, getMlrOptions()$on.par.out.of.bounds)
+  on.par.without.desc = coalesce(learner$config$on.par.without.desc, getMlrOption("on.par.without.desc"))
+  on.par.out.of.bounds = coalesce(learner$config$on.par.out.of.bounds, getMlrOption("on.par.out.of.bounds"))
+
   for (i in seq_along(par.vals)) {
     n = ns[i]
     p = par.vals[[i]]
     pd = pars[[n]]
     if (is.null(pd)) {
-      # no description: stop warn or quiet
-      msg = sprintf("%s: Setting parameter %s without available description object!\nYou can switch off this check by using configureMlr!", learner$id, n)
+      if (on.par.without.desc != "quiet") {
+        # no description: stop warn or quiet
+        msg = sprintf("%s: Setting parameter %s without available description object!", learner$id, n)
+        # since we couldn't find the par let's look for 3 most similar
+        parnames = names(pars)
+        indices = head(order(adist(n, parnames)), 3L)
+        possibles = parnames[indices]
+        if (length(possibles) > 0L) {
+          msg = paste0(msg, sprintf("\nDid you mean one of these hyperparameters instead: %s", stri_flatten(possibles, collapse = " ")))
+        }
+        msg = paste0(msg, "\nYou can switch off this check by using configureMlr!")
+      }
+
       if (on.par.without.desc == "stop") {
         stop(msg)
       } else if (on.par.without.desc == "warn") {
@@ -67,11 +81,13 @@ setHyperPars2.Learner = function(learner, par.vals) {
           warning(msg)
         }
       }
+
       ## if valname of discrete par was used, transform it to real value
       #if (pd$type == "discrete" && is.character(p) && length(p) == 1 && p %in% names(pd$values))
       #  p = pd$values[[p]]
       learner$par.vals[[n]] = p
     }
   }
+
   return(learner)
 }
