@@ -82,11 +82,10 @@ train = function(learner, task, subset, weights = NULL) {
       on.exit(options(warn = old.warn.opt))
       options(warn = -1L)
     }
-    st = system.time(fun1(learner.model <- fun2(do.call(trainLearner, pars))), gcFirst = FALSE)
+    time.train = measureTime(fun1(learner.model <- fun2(do.call(trainLearner, pars))))
     # was there an error during training? maybe warn then
     if (is.error(learner.model) && opts$on.learner.error == "warn")
       warningf("Could not train learner %s: %s", learner$id, as.character(learner.model))
-    time.train = as.numeric(st[3L])
   }
   factor.levels = getTaskFactorLevels(task)
   makeWrappedModel(learner, learner.model, getTaskDescription(task), subset, vars, factor.levels, time.train)
