@@ -8,13 +8,12 @@ tuneGenSA = function(learner, task, resampling, measures, par.set, control, opt.
     start = sampleValue(par.set, start, trafo = FALSE)
   start = convertStartToNumeric(start, par.set)
   ctrl.gensa = control$extra.args
-  cx = function(x) convertXNumeric(x, par.set)
 
   # FIXME: GenSA exceeds the given budget (if it is very low)!
   res = GenSA::GenSA(par = start, fn = tunerFitnFun, lower = low, upper = upp, control = ctrl.gensa,
     learner = learner, task = task, resampling = resampling, measures = measures,
     par.set = par.set, ctrl = control, opt.path = opt.path, show.info = show.info,
-    convertx = cx, remove.nas = FALSE)
+    convertx = convertXNumeric, remove.nas = FALSE)
 
   # FIXME: the following condition can be removed, once we are able to fix the
   # budget in GenSA
