@@ -98,7 +98,7 @@ testProb = function(t.name, df, target, train.inds, old.probs, parset = list())
   inds = train.inds
   train = df[inds,]
   test = df[-inds,]
-  
+
   if(length(target) == 1) {
     task = makeClassifTask(data = df, target = target)
   } else {
@@ -227,6 +227,29 @@ mylist = function(..., create = FALSE) {
 }
 
 testFacetting = function(obj, nrow = NULL, ncol = NULL) {
-  expect_equal(obj$facet$nrow, nrow)
-  expect_equal(obj$facet$ncol, ncol)
+  expect_equal(obj$facet$params$nrow, nrow)
+  expect_equal(obj$facet$params$ncol, ncol)
+}
+
+quickcheckTest = function(...) {
+  skip_if_not_installed("quickcheck")
+  qc = quickcheck::test(...)
+
+  if (any(!qc$pass)) {
+    print("Quickcheck tests failed with input:")
+    print(qc$cases[[which.first(!qc$pass)]])
+  }
+
+  expect_true(all(qc$pass), info = "Some Quickcheck tests failed.")
+}
+
+testDocForStrings = function(doc, x, grid.size = 1L, ordered = FALSE) {
+  text.paths = paste("/svg:svg//svg:text[text()[contains(., '",
+    x, "')]]", sep = "")
+  nodes = XML::getNodeSet(doc, text.paths, ns.svg)
+  expect_equal(length(nodes), length(x) * grid.size)
+  if (ordered) {
+    node.strings = vcapply(nodes, XML::getChildrenStrings)
+    expect_equal(node.strings[seq_along(x)], x)
+  }
 }
