@@ -10,9 +10,9 @@ test_that("generateLearningCurve", {
   path = paste0(dir, "/test.svg")
   ggsave(path)
   doc = XML::xmlParse(path)
-  #expect_that(length(XML::getNodeSet(doc, grey.xpath, ns.svg)), equals(length(r$measures)))
-  #expect_that(length(XML::getNodeSet(doc, red.line.xpath, ns.svg)) - 1, equals(length(unique(r$data$learner))))
-  #expect_that(length(XML::getNodeSet(doc, blue.line.xpath, ns.svg)) - 1, equals(length(unique(r$data$learner))))
+  expect_that(length(XML::getNodeSet(doc, grey.rect.xpath, ns.svg)), equals(length(r$measures)))
+  expect_that(length(XML::getNodeSet(doc, red.line.xpath, ns.svg)), equals(length(unique(r$data$learner))))
+  expect_that(length(XML::getNodeSet(doc, blue.line.xpath, ns.svg)), equals(length(unique(r$data$learner))))
   ## plotLearningCurveGGVIS(r)
 
   r = generateLearningCurveData(learners = list("regr.lm", "regr.svm"),
@@ -23,9 +23,9 @@ test_that("generateLearningCurve", {
   plotLearningCurve(r)
   ggsave(path)
   doc = XML::xmlParse(path)
-  #expect_that(length(XML::getNodeSet(doc, grey.xpath, ns.svg)), equals(length(r$measures)))
-  #expect_that(length(XML::getNodeSet(doc, red.line.xpath, ns.svg)) - 1, equals(length(unique(r$data$learner))))
-  #expect_that(length(XML::getNodeSet(doc, blue.line.xpath, ns.svg)) - 1, equals(length(unique(r$data$learner))))
+  expect_that(length(XML::getNodeSet(doc, grey.rect.xpath, ns.svg)), equals(length(r$measures)))
+  expect_that(length(XML::getNodeSet(doc, red.line.xpath, ns.svg)), equals(length(unique(r$data$learner))))
+  expect_that(length(XML::getNodeSet(doc, blue.line.xpath, ns.svg)), equals(length(unique(r$data$learner))))
   ## plotLearningCurveGGVIS(r)
 
   r = generateLearningCurveData(list("classif.rpart", "classif.knn"),
@@ -35,9 +35,9 @@ test_that("generateLearningCurve", {
   plotLearningCurve(r)
   ggsave(path)
   doc = XML::xmlParse(path)
-  #expect_that(length(XML::getNodeSet(doc, grey.xpath, ns.svg)), equals(length(r$measures)))
-  #expect_that(length(XML::getNodeSet(doc, red.line.xpath, ns.svg)) - 1, equals(length(unique(r$data$learner))))
-  #expect_that(length(XML::getNodeSet(doc, blue.line.xpath, ns.svg)) - 1, equals(length(unique(r$data$learner))))
+  expect_that(length(XML::getNodeSet(doc, grey.rect.xpath, ns.svg)), equals(length(r$measures)))
+  expect_that(length(XML::getNodeSet(doc, red.line.xpath, ns.svg)), equals(length(unique(r$data$learner))))
+  expect_that(length(XML::getNodeSet(doc, blue.line.xpath, ns.svg)), equals(length(unique(r$data$learner))))
   ## plotLearningCurveGGVIS(r)
 
   # facetting works for plotLearningCurveData
@@ -48,3 +48,10 @@ test_that("generateLearningCurve", {
   testFacetting(q, ncol = 2L)
 
 })
+
+test_that("generateLearningCurve works if single learner is passed (not wrapped in list)", {
+  # see issue #1046
+  r = generateLearningCurveData(makeLearner("classif.rpart"), task = binaryclass.task,
+    percs = c(0.1, 0.7), measures = list(acc, timeboth))
+  expect_true(all(c("learner", "percentage", "acc", "timeboth") %in% colnames(r$data)))
+})
