@@ -10,9 +10,9 @@ test_that("hyperpars", {
 
   # test equality after removing using removeHyperPars
   lrn = makeLearner("classif.J48", C=0.5)
-  expect_identical(getHyperPars(makeLearner("classif.J48")), 
+  expect_identical(getHyperPars(makeLearner("classif.J48")),
     getHyperPars(removeHyperPars(lrn, "C")))
-  
+
   # test a more complex param object
   lrn = makeLearner("classif.ksvm", class.weights = c(setosa = 1, versicolor = 2, virginica = 3))
   m = train(lrn, task = multiclass.task)
@@ -43,7 +43,7 @@ test_that("removing par settings works", {
   expect_equal(getHyperPars(lrn3), list(bw.iters = 9))
   lrn3 = removeHyperPars(lrn2, "bw.iters")
   expect_equal(getHyperPars(lrn3), list(method = "mve"))
-  
+
   # now remove all hyperpars using a wrapped wrapper
   lrn = makeOversampleWrapper(makeFilterWrapper(makeLearner("classif.qda", nu = 2), fw.perc = 0.5), osw.rate = 1)
   lrn1 = removeHyperPars(lrn, ids = names(getHyperPars(lrn)))
@@ -61,7 +61,39 @@ test_that("setting 'when' works for hyperpars", {
   expect_equal(p$data$response, rep(1+2+2*3, getTaskSize(regr.task)))
 })
 
+test_that("fuzzy matching works for mistyped hyperpars", {
+  msg = "classif.ksvm: Setting parameter sigm without available description object!\nDid you mean one of these hyperparameters instead: sigma fit type\nYou can switch off this check by using configureMlr!"
+  mlr.opts = getMlrOptions()
 
+  # test if config arg works properly in combination with show.info
+  cq = list(on.par.without.desc = "quiet")
+  cw = list(on.par.without.desc = "warn")
+  cs = list(on.par.without.desc = "stop")
+  # never print message when quiet
+  expect_silent(makeLearner("classif.ksvm", config = cq, sigm = 1))
+  configureMlr(on.par.without.desc = "quiet")
+  expect_silent(makeLearner("classif.ksvm", sigm = 1))
+
+  # print message and warn
+  expect_warning(makeLearner("classif.ksvm", config = cw, sigm = 1), msg)
+  configureMlr(on.par.without.desc = "warn")
+  expect_warning(makeLearner("classif.ksvm", sigm = 1), msg)
+
+  # print message and error
+  expect_error(makeLearner("classif.ksvm", config = cs, sigm = 1), msg)
+  configureMlr(on.par.without.desc = "stop")
+  expect_error(makeLearner("classif.ksvm", sigm = 1), msg)
+
+  # docu says: for warn and quiet parameter is passed, check if this is true
+  lrn = makeLearner("classif.ksvm",
+    config = list(on.par.without.desc = "quiet"))
+  expect_equal(getHyperPars(setHyperPars(lrn, sigm = 1))$sigm, 1)
+  lrn = makeLearner("classif.ksvm",
+    config = list(on.par.without.desc = "warn"))
+  expect_warning(expect_equal(getHyperPars(setHyperPars(lrn, sigm = 1))$sigm, 1))
+
+  do.call(configureMlr, mlr.opts)
+})
 
 test_that("options are respected", {
   # with local option
