@@ -1,4 +1,4 @@
-context("OverBagging")
+context("overbagging")
 
 test_that("OverBagging wrapper",  {
   rdesc = makeResampleDesc("CV", iters = 2)
@@ -22,6 +22,7 @@ test_that("oversampling in each bag works", {
    lrn2 = makeOverBaggingWrapper(lrn1, obw.rate = 5, obw.iters = 3)
    mod = train(lrn2, task)
    models = getLearnerModel(mod)
+
    # check min class size gets increased by rate/factor 5
    tab = lapply(1:length(models), function(i) {
      data = getTaskData(task, models[[i]]$subset)
@@ -30,3 +31,21 @@ test_that("oversampling in each bag works", {
      expect_equal(tab1["R"], round(tab["R"] / 5))
    })
 })
+
+test_that("oversampling bigger class works", {
+   y = binaryclass.df[, binaryclass.target]
+   z = getMinMaxClass(y)
+   tab1 = table(y)
+   task = makeClassifTask(data = binaryclass.df, target = binaryclass.target)
+   lrn1 = makeLearner("classif.rpart")
+   lrn2 = makeOverBaggingWrapper(lrn1, obw.rate = 5, obw.iters = 3, obw.cl = z$max.name)
+   mod = train(lrn2, task)
+   models = getLearnerModel(mod)
+
+   tab = lapply(1:length(models), function(i) {
+     data = getTaskData(task, models[[1]]$subset)
+     tab = table(data[, binaryclass.target])
+     expect_equal(tab1["R"], tab["R"])
+     expect_equal(tab1["M"], round(tab["M"] / 5))
+   })
+})
