@@ -12,5 +12,18 @@ test_that("BenchmarkSummary", {
   plotBMRSummary(res)
 
   # pretty.names works
+  plotBMRSummary(res)
+  dir = tempdir()
+  path = paste0(dir, "/test.svg")
+  ggsave(path)
+  doc = XML::xmlParse(path)
+  testDocForStrings(doc, getBMRLearnerShortNames(res))
+  
   plotBMRSummary(res, pretty.names = FALSE)
+  dir = tempdir()
+  path = paste0(dir, "/test.svg")
+  ggsave(path)
+  doc = XML::xmlParse(path)
+  testDocForStrings(doc, getBMRLearnerIds(res))
+  
 })
