@@ -123,7 +123,7 @@ test_that("predict.threshold", {
 
   # now with wrapper
   lrn1 = makeLearner("classif.lda")
-  lrn2 = makeFilterWrapper(lrn1, fw.method = "chi.squared", fw.perc = 0.1)
+  lrn2 = makeFilterWrapper(lrn1, fw.method = "anova.test", fw.perc = 0.1)
   lrn2 = setPredictType(lrn2, "prob")
   lrn2 = setPredictThreshold(lrn2, 0)
   r = holdout(lrn2, binaryclass.task)
@@ -137,3 +137,10 @@ test_that("predict doesn't warn if 'on.learner.error' is 'quiet'", {
   expect_true(inherits(mod, "FailureModel"))
   expect_warning(predict(mod, multiclass.task), NA)
 })
+
+test_that("predict works with data.table as newdata", {
+  lrn = makeLearner("classif.qda")
+  mod = train(lrn, iris.task)
+  expect_warning(predict(mod, newdata = data.table(iris)), regexp = "Provided data for prediction is not a pure data.frame but from class data.table, hence it will be converted.")
+})
+
