@@ -6,9 +6,13 @@ test_that("resample", {
   rin3 = makeResampleInstance(makeResampleDesc("Subsample", iters = 2), task = multiclass.task)
 
   lrn = makeLearner("classif.lda")
-  p1 = resample(lrn, multiclass.task, rin1)$pred
-  p2 = resample(lrn, multiclass.task, rin2)$pred
-  p3 = resample(lrn, multiclass.task, rin3)$pred
+  r1 = resample(lrn, multiclass.task, rin1)
+  r2 = resample(lrn, multiclass.task, rin2)
+  r3 = resample(lrn, multiclass.task, rin3)
+
+  p1 = r1$pred
+  p2 = r2$pred
+  p3 = r3$pred
 
   inds = Reduce(c, rin1$test.inds)
   y = getTaskTargets(multiclass.task)[inds]
@@ -22,6 +26,9 @@ test_that("resample", {
   y = getTaskTargets(multiclass.task)[inds]
   expect_equal(p3$data$id, inds)
   expect_equal(p3$data$truth, y)
+  # test printer
+  expect_output(print(r1), "Resample Result")
+
 
   cv.i = makeResampleInstance(makeResampleDesc("CV", iters = 3), binaryclass.task)
 
@@ -51,22 +58,31 @@ test_that("resample", {
 test_that("resampling, predicting train set works", {
   rdesc = makeResampleDesc("CV", iters = 2, predict = "train")
   lrn = makeLearner("classif.rpart")
-  r = resample(lrn, multiclass.task, rdesc)
-  expect_true(as.logical(is.na(r$aggr["mmce.test.mean"])))
+  expect_error(resample(lrn, multiclass.task, rdesc), "not compatible with resampling")
 
   rdesc = makeResampleDesc("CV", iters = 2, predict = "train")
   lrn = makeLearner("classif.rpart")
   m = setAggregation(mmce, train.mean)
   r = resample(lrn, multiclass.task, rdesc, measures = m)
-  expect_true(!as.logical(is.na(r$aggr["mmce.train.mean"])))
-
+  expect_false(is.na(r$aggr["mmce.train.mean"]))
+  expect_false(anyNA(r$pred$time))
+  expect_false(is.null(r$pred$predict.type))
+  expect_false(is.null(r$pred$threshold))
+  expect_equal(getTaskDescription(multiclass.task), r$pred$task.desc)
+  
   rdesc = makeResampleDesc("CV", iters = 2, predict = "both")
   lrn = makeLearner("classif.rpart")
   m1 = setAggregation(mmce, train.mean)
   m2 = setAggregation(mmce, test.mean)
   r = resample(lrn, multiclass.task, rdesc, measures = list(m1, m2))
-  expect_true(!as.logical(is.na(r$aggr["mmce.train.mean"])))
-  expect_true(!as.logical(is.na(r$aggr["mmce.test.mean"])))
+  expect_false(is.na(r$aggr["mmce.train.mean"]))
+  expect_false(is.na(r$aggr["mmce.test.mean"]))
+  expect_false(anyNA(r$pred$time))
+  expect_false(is.null(r$pred$predict.type))
+  expect_false(is.null(r$pred$threshold))
+  expect_equal(getTaskDescription(multiclass.task), r$pred$task.desc)
+  
+  
 
 })
 
@@ -130,3 +146,37 @@ test_that("resample has error messages when prediction fails", {
   configureMlr(on.learner.error = on.learner.error.saved)
   configureMlr(on.learner.warning = on.learner.warning.saved)
 })
+
+
+test_that("resample is extended by an additional measure", {
+  lrn = makeLearner("classif.rpart", predict.type = "prob")
+
+  # check if it works with test, both
+  # FIXME: add "train" after https://github.com/mlr-org/mlr/issues/1284 has been fixed
+  predict = c("test", "both")
+  # check if it works with different aggregation methods
+  aggr = list(test.mean, test.median, test.sd, test.range, test.join)
+  for (a in aggr) {
+    for (p in predict) {
+      rdesc = makeResampleDesc("CV", iter = 3, predict = p)
+      measures = list(mmce, ber, auc, brier)
+      # set aggregation method
+      measures = lapply(measures, setAggregation, a)
+      #if (p == "train") measures = lapply(measures, setAggregation, train.mean)
+      # create ResampleResult with all measures
+      res.all = resample(lrn, binaryclass.task, rdesc, measures)
+      # create ResampleResult with one measure and add the other ones afterwards
+      res = resample(lrn, binaryclass.task, rdesc, measures[[1]])
+      res.add = addRRMeasure(res, measures[-1])
+
+      # check if both ResampleResult objects are equal
+      expect_equal(res.all$measures.train, res.add$measures.train)
+      expect_equal(res.all$measures.test, res.add$measures.test)
+      expect_equal(res.all$aggr, res.add$aggr)
+    }
+  }
+
+  # keep.pred must be TRUE
+  res = resample(lrn, binaryclass.task, cv3, mmce, keep.pred = FALSE)
+  expect_error(addRRMeasure(res, auc), "keep.pred")
+})
