@@ -1,4 +1,4 @@
-context("b632+")
+context("resample_b632+")
 
 test_that("b632+", {
   res = makeResampleDesc("Bootstrap", iters=3, predict="both")
