@@ -1,8 +1,15 @@
 context("classif_binomial")
 
 test_that("classif_binomial", {
+  
+  parset.list1 = list(
+    list(family = binomial),
+    list(family = binomial(link = "logit")),
+    list(family = binomial(link = "cloglog"))
+  )
 
-  parset.list = list(
+  parset.list2 = list(
+    list(),
     list(link = "logit"),
     list(link = "cloglog")
   )
@@ -11,10 +18,10 @@ test_that("classif_binomial", {
   old.probs.list = list()
   nof = 1:55 # remove feats
 
-  for (i in 1:length(parset.list)) {
-    parset = parset.list[[i]]
+  for (i in 1:length(parset.list1)) {
+    parset = parset.list1[[i]]
     set.seed(getOption("mlr.debug.seed"))
-    m = glm(formula = binaryclass.formula, data = binaryclass.train[, -nof], family = binomial(link = parset$link))
+    m = glm(formula = binaryclass.formula, data = binaryclass.train[, -nof], family = parset$family)
     p  = predict(m, newdata = binaryclass.test[,-nof], type = "response")
     p = 1 - p
     p.class = as.factor(binaryclass.class.levs[ifelse(p > 0.5, 1, 2)])
@@ -23,7 +30,7 @@ test_that("classif_binomial", {
   }
 
   testSimpleParsets("classif.binomial", binaryclass.df[,-nof], binaryclass.target, binaryclass.train.inds,
-    old.predicts.list, parset.list)
+    old.predicts.list, parset.list2)
   testProbParsets  ("classif.binomial", binaryclass.df[,-nof], binaryclass.target, binaryclass.train.inds,
-    old.probs.list, parset.list)
+    old.probs.list, parset.list2)
 })
