@@ -1,7 +1,8 @@
 context("classif_multinom")
 
 test_that("classif_multinom", {
-  requirePackages("nnet", default.method = "load")
+  requirePackagesOrSkip("nnet", default.method = "load")
+
   set.seed(getOption("mlr.debug.seed"))
   capture.output(m <- nnet::multinom(formula = multiclass.formula, data = multiclass.train))
 
