@@ -11,96 +11,52 @@ test_that("learners work: classif ", {
       replace_missing_data_with_x_j_bar = TRUE,
       num_iterations_after_burn_in = 10L),
     classif.bdk = list(ydim = 2L),
+    classif.earth = list(degree = 3L, nprune = 2L),
     classif.gbm = list(bag.fraction = 1, n.minobsinnode = 1),
     classif.lssvm = list(kernel = "rbfdot", reduced = FALSE),
     classif.nodeHarvest = list(nodes = 100L, nodesize = 5L),
-    classif.xyf = list(ydim = 2L)
+    classif.xyf = list(ydim = 2L),
+    classif.h2o.deeplearning = list(hidden = 2L, seed = getOption("mlr.debug.seed"), reproducible = TRUE),
+    classif.h2o.randomForest = list(seed = getOption("mlr.debug.seed"))
   )
 
-  fixHyperPars = function(lrn) {
-    if (lrn$id %in% names(hyperpars))
-      lrn = setHyperPars(lrn, par.vals = hyperpars[[lrn$id]])
-    return(lrn)
-  }
-
   # binary classif
   task = subsetTask(binaryclass.task, subset = c(10:20, 180:190),
     features = getTaskFeatureNames(binaryclass.task)[12:15])
   lrns = mylist(task, create = TRUE)
-  for (lrn in lrns) {
-    expect_output(print(lrn), lrn$id)
-    lrn = fixHyperPars(lrn)
-    m = train(lrn, task)
-    p = predict(m, task)
-    expect_true(!is.na(performance(p)))
-  }
+  lapply(lrns, testThatLearnerParamDefaultsAreInParamSet)
+  lapply(lrns, testBasicLearnerProperties, task = task, hyperpars = hyperpars)
 
   # binary classif with factors
-  data = binaryclass.df[c(10:20, 180:190), 12:15]
-  data[, 4L] = factor(sample(c("a", "b"), size = nrow(data), replace = TRUE))
-  data$y = binaryclass.df[c(10:20, 180:190),binaryclass.target]
-  task = makeClassifTask(data = data, target = "y")
-  lrns = mylist(task, create = TRUE)
-  for (lrn in lrns) {
-    expect_output(print(lrn), lrn$id)
-    lrn = fixHyperPars(lrn)
-    m = train(lrn, task)
-    p = predict(m, task)
-    expect_true(!is.na(performance(p)))
-  }
+  lrns = mylist("classif", properties = "factors", create = TRUE)
+  lapply(lrns, testThatLearnerHandlesFactors, task = task, hyperpars = hyperpars)
+
+  # binary classif with ordered factors
+  lrns = mylist("classif", properties = "ordered", create = TRUE)
+  lapply(lrns, testThatLearnerHandlesOrderedFactors, task = task, hyperpars = hyperpars)
 
   # binary classif with prob
-  task = subsetTask(binaryclass.task, subset = c(1:10, 180:190),
-    features = getTaskFeatureNames(binaryclass.task)[12:15])
-  lrns = mylist(task, properties = "prob")
-  lrns = lapply(lrns$class, makeLearner, predict.type = "prob")
-  lapply(lrns, function(lrn) {
-    lrn = fixHyperPars(lrn)
-    m = train(lrn, task)
-    p = predict(m, task)
-    getPredictionProbabilities(p)
-    expect_true(!is.na(performance(p)))
-  })
+  lrns = mylist(binaryclass.task, properties = "prob", create = TRUE)
+  lapply(lrns, testBasicLearnerProperties, task = binaryclass.task,
+    hyperpars = hyperpars, pred.type = "prob")
 
   # binary classif with weights
-  task = makeClassifTask(data = binaryclass.df, target = binaryclass.target)
-  task = subsetTask(task, subset = c(1:10, 150:160), features = getTaskFeatureNames(task)[1:2])
-  lrns = mylist(task, properties = "weights")
-  lrns = lapply(lrns$class, makeLearner)
-  lapply(lrns, function(lrn) {
-    lrn = fixHyperPars(lrn)
-    m = train(lrn, task, weights = 1:getTaskSize(task))
-    p = predict(m, task)
-    expect_true(!is.na(performance(p)))
-  })
+  lrns = mylist("classif", properties = "weights", create = TRUE)
+  lapply(lrns, testThatLearnerRespectsWeights, hyperpars = hyperpars,
+    task = binaryclass.task, train.inds = binaryclass.train.inds, test.inds = binaryclass.test.inds,
+    weights = rep(c(10000L, 1L), c(10L, length(binaryclass.train.inds) - 10L)),
+    pred.type = "prob", get.pred.fun = getPredictionProbabilities)
 
   # classif with missing
-  d = binaryclass.df[c(1:10, 180:190), c(1:2, binaryclass.class.col)]
-  d[1, 1] = NA
-  task = makeClassifTask(data = d, target = binaryclass.target)
-  lrns = mylist(task, create = TRUE)
-  for (lrn in lrns) {
-    lrn = fixHyperPars(lrn)
-    m = train(lrn, task)
-    p = predict(m, task)
-    expect_true(!is.na(performance(p)))
-  }
-
-  # classif with factors
-  d = binaryclass.df[c(1:10, 181:190), c(1:2, binaryclass.class.col)]
-  d[, 2] = factor(rep(c("a", "b", "b", "a"), each = 5L))
-  task = makeClassifTask(data = d, target = binaryclass.target)
-  lrns = mylist(task, create = TRUE)
-  for (lrn in lrns) {
-    lrn = fixHyperPars(lrn)
-    m = train(lrn, task)
-    p = predict(m, task)
-    expect_true(!is.na(performance(p)))
-  }
-
+  lrns = mylist("classif", properties = "missings", create = TRUE)
+  lapply(lrns, testThatLearnerHandlesMissings, task = task, hyperpars = hyperpars)
 
+  # classif with variable importance
+  lrns = mylist("classif", properties = "featimp", create = TRUE)
+  lapply(lrns, testThatLearnerCanCalculateImportance, task = task, hyperpars = hyperpars)
 })
 
+
 test_that("weightedClassWrapper on all binary learners",  {
   pos = getTaskDescription(binaryclass.task)$positive
   f = function(lrn, w) {
@@ -108,7 +64,7 @@ test_that("weightedClassWrapper on all binary learners",  {
     lrn2 = makeWeightedClassesWrapper(lrn1, wcw.weight = w)
     m = train(lrn2, binaryclass.task)
     p = predict(m, binaryclass.task)
-    cm = getConfMatrix(p)
+    cm = calculateConfusionMatrix(p)$result
   }
 
   learners = listLearners(binaryclass.task, "class.weights")
@@ -121,6 +77,7 @@ test_that("weightedClassWrapper on all binary learners",  {
   })
 })
 
+
 test_that("WeightedClassWrapper on all multiclass learners",  {
   levs = getTaskClassLevels(multiclass.task)
   f = function(lrn, w) {
@@ -129,7 +86,7 @@ test_that("WeightedClassWrapper on all multiclass learners",  {
     lrn2 = makeWeightedClassesWrapper(lrn1, wcw.weight = w)
     m = train(lrn2, multiclass.task)
     p = predict(m, multiclass.task)
-    cm = getConfMatrix(p)
+    cm = calculateConfusionMatrix(p)$result
   }
 
   learners = listLearners(multiclass.task, "class.weights")
@@ -147,4 +104,3 @@ test_that("WeightedClassWrapper on all multiclass learners",  {
     expect_true(all(cm3[, levs[3]] >= cm2[, levs[3]]))
   })
 })
-
