@@ -20,7 +20,8 @@ test_that("learners work: regr ", {
   
   # normal regr
   lrns = mylist("regr", create = TRUE)
-  lapply(lrns, testThatLearnerCanTrainPredict, task = task, hyperpars = hyperpars)
+  lapply(lrns, testThatLearnerParamDefaultsAreInParamSet)
+  lapply(lrns, testBasicLearnerProperties, task = task, hyperpars = hyperpars)
 
   # regr with factors
   lrns = mylist("regr", properties = "factors", create = TRUE)
@@ -32,7 +33,7 @@ test_that("learners work: regr ", {
 
   # regr with se
   lrns = mylist(task, properties = "se", create = TRUE)
-  lapply(lrns, testThatLearnerCanTrainPredict, task = task, hyperpars = hyperpars,
+  lapply(lrns, testBasicLearnerProperties, task = task, hyperpars = hyperpars,
     pred.type = "se")
 
   # regr with weights
@@ -44,5 +45,9 @@ test_that("learners work: regr ", {
   # regr with missing
   lrns = mylist("regr", properties = "missings", create = TRUE)
   lapply(lrns, testThatLearnerHandlesMissings, task = task, hyperpars = hyperpars) 
+  
+  # regr variable importance
+  lrns = mylist("regr", properties = "featimp", create = TRUE)
+  lapply(lrns, testThatLearnerCanCalculateImportance, task = task, hyperpars = hyperpars) 
 
 })
