@@ -1,3 +1,6 @@
+context("learners_classiflabelswitch")
+
+if (FALSE) {
 
 n = 50L
 p = 2L
@@ -34,7 +37,8 @@ hpars = list(
   classif.lssvm = list(kernel = "rbfdot", sigma = 0.4, reduced = FALSE),
   classif.LiblineaRLogReg = list(type = 7),
   classif.LiblineaRBinary = list(type = 1),
-  classif.LiblineaRMultiClass = list(type = 1)
+  classif.LiblineaRMultiClass = list(type = 1),
+  classif.nodeHarvest = list(nodes = 100L, maxinter = 1L)
 )
 
 
@@ -49,21 +53,19 @@ test_that("no labels are switched", {
     names(lrns) = lids
     toremove = grepl("classif.mock", lids)
     toremove = toremove | grepl("classif.LiblineaRMultiClass", lids)
-    #FIXME: nodeHarvest does not yet pass this test
-    toremove = toremove | grepl("classif.nodeHarvest", lids)
+    toremove = toremove | grepl("classif.h2o", lids)
     lrns = lrns[!toremove]
 
-    errs = vnapply(lrns, function(lrn) {
+    vnapply(lrns, function(lrn) {
       lrn = setPredictType(lrn, predtype)
       id = lrn$id
       hps = hpars[[id]]
       if (!is.null(hps))
         lrn = setHyperPars(lrn, par.vals = hps)
-      holdout(lrn, task, split = 0.5, stratify = TRUE)$aggr[[1L]]
+      err = holdout(lrn, task, split = 0.5, stratify = TRUE)$aggr[[1L]]
+      expect_true(!is.na(err) & err <= 1/3, info = paste(getTaskDescription(task)$id, id, err, sep = ", "))
+      err
     })
-    expect_true(all(!is.na(errs) & errs <= 0.3))
-    # messagef("predtype = %s; task = %s", predtype, task$task.desc$id)
-    # print(sort(errs, na.last = TRUE))
   }
   # FIXME: only check prob for now for timimg reasons
   for (predtype in c("prob")) {
@@ -76,3 +78,4 @@ test_that("no labels are switched", {
   }
 })
 
+}
