@@ -3,18 +3,27 @@ context("regr_LiblineaRL2L2SVR")
 test_that("regr_LiblineaRL2L2SVR", {
   requirePackagesOrSkip("LiblineaR", default.method = "load")
 
-  parset.list = list(
+  parset.list1 = list(
+    list(type = 11),
     list(type = 11, svr_eps = 0.01),
     list(type = 12, svr_eps = 0.1),
     list(type = 11, cost = 5L),
     list(type = 12, cost = 5L)
   )
+  
+  parset.list2 = list(
+    list(),
+    list(svr_eps = 0.01),
+    list(type = 12, svr_eps = 0.1),
+    list(cost = 5L),
+    list(type = 12, cost = 5L)
+  )
 
   old.predicts.list = list()
   old.probs.list = list()
 
-  for (i in 1L:length(parset.list)) {
-    parset = parset.list[[i]]
+  for (i in 1L:length(parset.list1)) {
+    parset = parset.list1[[i]]
     pars = list(data = regr.num.train[, -regr.num.class.col],
       target = regr.num.train[, regr.num.target])
     pars = c(pars, parset)
@@ -24,13 +33,7 @@ test_that("regr_LiblineaRL2L2SVR", {
     p = predict(m, newx = regr.num.test[, -regr.num.class.col])
     old.predicts.list[[i]] = p$predictions
   }
-  parset.list = list(
-    list(svr_eps = 0.01),
-    list(type = 12, svr_eps = 0.1),
-    list(cost = 5L),
-    list(type = 12, cost = 5L)
-  )
-
+  
   testSimpleParsets("regr.LiblineaRL2L2SVR", regr.num.df, regr.num.target,
-    regr.num.train.inds, old.predicts.list, parset.list)
+    regr.num.train.inds, old.predicts.list, parset.list2)
 })
