@@ -1,11 +1,14 @@
 context("regr_randomForest")
 
 test_that("regr_randomForest", {
-  requirePackages("randomForest", default.method = "load")
+  requirePackagesOrSkip("randomForest", default.method = "load")
+
   parset.list = list(
     list(),
     list(ntree = 5, mtry = 2),
-    list(ntree = 5, mtry = 4)
+    list(ntree = 5, mtry = 4),
+    list(proximity = TRUE, oob.prox = TRUE),
+    list(nPerm = 3)
   )
 
   old.predicts.list = list()
@@ -61,3 +64,14 @@ test_that("different se.methods work", {
     expect_true(all(pred.one$data$se >= 0))
   }
 })
+
+
+test_that("dplyr data.frames work", {
+  data("mpg", package = "ggplot2")
+  mpg$model = NULL
+  for (cname in colnames(mpg)[sapply(mpg, is.character)])
+    mpg[[cname]] = as.factor(mpg[[cname]])
+  expect_warning((task_mpg = makeRegrTask(data = mpg, target = "cty")), "Provided data is not a pure data.frame but from class")
+  lrn = makeLearner("regr.randomForest", ntree = 2)
+  train(lrn, task_mpg)
+})
