@@ -1,7 +1,8 @@
 context("regr_rsm")
 
 test_that("regr_rsm", {
-  requirePackages("rsm", default.method = "load")
+  requirePackagesOrSkip("rsm", default.method = "load")
+
   data = regr.df[, c("b", "lstat", "medv")]
   pars = list(medv ~ FO(b, lstat), data=data[regr.train.inds,])
   set.seed(getOption("mlr.debug.seed"))
