@@ -121,3 +121,15 @@ test_that("tuneParamsMultiCrit with budget", {
   expect_equal(ctrl$extra.args$generations, 2L)
   mycheck(ctrl, 12L)
 })
+
+test_that("plotTuneMultiCritResult works with pretty.names", {
+  lrn = makeLearner("classif.rpart")
+  ps = makeParamSet(
+    makeDiscreteParam("minsplit", values = c(5, 10))
+    )
+  ctrl.grid = makeTuneMultiCritControlGrid() 
+  opt.multi.crit = tuneParamsMultiCrit(lrn, multiclass.task, hout,
+    list(mmce, acc), par.set = ps, control = ctrl.grid)
+  plotTuneMultiCritResult(opt.multi.crit)
+  plotTuneMultiCritResult(opt.multi.crit, pretty.names = FALSE)
+})
\ No newline at end of file
